==> 0.4.0.tar.gz: example/lib/views/dropdown_button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class DropdownButtonExample extends StatefulWidget {
  const DropdownButtonExample({Key? key}) : super(key: key);

  @override
  _DropdownButtonExampleState createState() => _DropdownButtonExampleState();
}

class _DropdownButtonExampleState extends State<DropdownButtonExample> {
  bool _isDisabled = false;
  List<DropdownMenuItem> items = [
    DropdownMenuItem(
      value: 'java',
      child: Text('Java'),
    ),
    DropdownMenuItem(
      value: 'javascript',
      child: Text('Javascript'),
    ),
    DropdownMenuItem(
      value: 'dart',
      child: Text('Dart'),
    )
  ];

  void showSnack({dynamic value, required BuildContext context}) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SeniorSnackBar.info(
        message: 'Selecionou $value',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Dropdown Button Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar campos',
                value: !this._isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    this._isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Normal',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        items: this.items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        disabled: this._isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Ícone à esquerda',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        icon: FontAwesomeIcons.globeAmericas,
                        items: this.items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        disabled: this._isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Com validator',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        icon: FontAwesomeIcons.globeAmericas,
                        items: this.items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        validator: (value) => value != this.items[2].value
                            ? 'Esta linguagem não é usada no Flutter'
                            : null,
                        disabled: this._isDisabled,
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.15.5.tar.gz: example/lib/views/dropdown_button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class DropdownButtonExample extends StatefulWidget {
  const DropdownButtonExample({Key? key}) : super(key: key);

  @override
  _DropdownButtonExampleState createState() => _DropdownButtonExampleState();
}

class _DropdownButtonExampleState extends State<DropdownButtonExample> {
  bool _isDisabled = false;
  List<DropdownMenuItem> items = [
    DropdownMenuItem(
      value: 'java',
      child: Text('Java'),
    ),
    DropdownMenuItem(
      value: 'javascript',
      child: Text('Javascript'),
    ),
    DropdownMenuItem(
      value: 'dart',
      child: Text('Dart'),
    )
  ];

  void showSnack({dynamic value, required BuildContext context}) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text('Selecionou $value'),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Dropdown Button Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar campos',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Normal',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        items: items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Ícone à esquerda',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        icon: FontAwesomeIcons.globeAmericas,
                        items: items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Com validator',
                      content: SeniorDropdownButton(
                        label: 'Linguagens',
                        icon: FontAwesomeIcons.globeAmericas,
                        items: items,
                        value: null,
                        onChanged: (value) {
                          showSnack(value: value, context: context);
                        },
                        validator: (value) => value != items[2].value
                            ? 'Esta linguagem não é usada no Flutter'
                            : null,
                        disabled: _isDisabled,
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
